@@ -1,9 +1,12 @@
 # flake8: noqa
-
+# fmt: off
 from voluptuous.schema_builder import *
-from voluptuous.validators import *
 from voluptuous.util import *
-from voluptuous.error import *
+from voluptuous.validators import *
 
-__version__ = '0.14.0'
+from voluptuous.error import *  # isort: skip
+
+# fmt: on
+
+__version__ = '0.14.2'
 __author__ = 'alecthomas'
